local name, addon = ...;
local version = GetAddOnMetadata(name, "Version");
local WBi = {};
local main,events,stat,check,warning = nil; -- FRAME VARIABLES
local StartBtn,CallBtn,CancelBtn,InputGrp,PlayerBox,RealmBox,AmountBox,InviteBtn,CancelInviteBtn,StatusGrp,EnemyFrame,CurrentBetFrame,CurrentRollFrame,ChanceFrame,WinnerFrame,CloseMainBtn,EndGameBtn = nil; -- MAIN FRAME VARIABLES
local PlayerMenu,HighWinFrame,HighLoseFrame,LongGameFrame,WorstRollFrame,WorstChanceFrame,TotalWinFrame,TotalLoseFrame,GoldRatioFrame = nil; -- UPPER STATS FRAME VARIABLES
local TotalLabel,GamesFrame,WinFrame,LossFrame,WinRatioFrame,CancelFrame,WinPercFrame,CancelPercFrame,BalanceFrame,CloseStatBtn = nil; -- LOWER STATS FRAME VARIABLES
local OfferLabel,AcceptBtn,DeclineBtn = nil; -- CHECK FRAME VARIABLES

WBi.ldb = LibStub:GetLibrary("LibDataBroker-1.1");
WBi.ldbIcon = LibStub:GetLibrary("LibDBIcon-1.0");

addon.vars = {
	['rollOutcome'] = 0,
	['rollCount'] = 0,
	['curBid'] = 0,
	['guestName'] = nil,
	['guestFullName'] = nil,
	['guestRealm'] = nil,
	['playCheck'] = false,
	['checkName'] = nil,
	['isStarted'] = false,
	['isOpen'] = false,
	['isOnline'] = false,
	['channel'] = nil,
	['myRealm'] = GetRealmName(),
	['isClientValid'] = GetCVar("portal"),
	['clientWarned'] = false,
};

addon.totals = {
	['overall'] = 0,
	['wins'] = 0,
	['cancels'] = 0,
	['losses'] = 0,
	['winP'] = 0,
	['canP'] = 0,
	['games'] = 0,
	['ratio'] = 0,
}

addon.EventFrame = CreateFrame("Frame");
addon.MainFrame = CreateFrame("Frame","MainFrame",UIParent);
addon.StatsFrame = CreateFrame("Frame","StatsFrame",UIParent);
addon.CheckFrame = CreateFrame("Frame","CheckFrame",UIParent);
addon.WarningFrame = CreateFrame("Frame","WarningFrame",UIParent);

events = addon.EventFrame;
main = addon.MainFrame;
stat = addon.StatsFrame;
check = addon.CheckFrame;
warning = addon.WarningFrame;

events:RegisterEvent("ADDON_LOADED");

local function initFrameVars()
	 -- MAIN FRAME VARIABLES
	StartBtn = addon.StartBtn;
	CallBtn = addon.CallBtn;
	CancelBtn = addon.CancelBtn;
	InputGrp = addon.InputGrp;
	PlayerBox = addon.PlayerBox;
	RealmBox = addon.RealmBox;
	AmountBox = addon.AmountBox;
	InviteBtn = addon.InviteBtn;
	CancelInviteBtn = addon.CancelInviteBtn;
	StatusGrp = addon.StatusGrp;
	EnemyFrame = addon.EnemyFrame;
	CurrentBetFrame = addon.CurrentBetFrame;
	CurrentRollFrame = addon.CurrentRollFrame;
	ChanceFrame = addon.ChanceFrame;
	WinnerFrame = addon.WinnerFrame;
	CloseMainBtn = addon.CloseMainBtn;
	EndGameBtn = addon.EndGameBtn;
	
	 -- STATS FRAME VARIABLES
	PlayerMenu = addon.PlayerMenu;
	HighWinFrame = addon.HighWinFrame;
	HighLoseFrame = addon.HighLoseFrame;
	LongGameFrame = addon.LongGameFrame;
	WorstRollFrame = addon.WorstRollFrame;
	WorstChanceFrame = addon.WorstChanceFrame;
	TotalWinFrame = addon.TotalWinFrame;
	TotalLoseFrame = addon.TotalLoseFrame;
	GoldRatioFrame = addon.GoldRatioFrame;
	TotalLabel = addon.TotalLabel;
	GamesFrame = addon.GamesFrame;
	WinFrame = addon.WinFrame;
	LossFrame = addon.LossFrame;
	WinRatioFrame = addon.WinRatioFrame;
	CancelFrame = addon.CancelFrame;
	WinPercFrame = addon.WinPercFrame;
	CancelPercFrame = addon.CancelPercFrame;
	BalanceFrame = addon.BalanceFrame;
	CloseStatBtn = addon.CloseStatBtn;
	
	 -- CHECK FRAME VARIABLES
	OfferLabel = addon.OfferLabel;
	AcceptBtn = addon.AcceptBtn;
	DeclineBtn = addon.DeclineBtn;
end

local function initPlayerMenu(self,level)
	local info;
	--addon.playerItems = {};
	info = UIDropDownMenu_CreateInfo();
	info.text = "Overall";
	info.value = "Overall";
	info.arg1 = 1;
	info.func = PlayerMenuChanged;
	UIDropDownMenu_AddButton(info);
	
	local ctr = 2;
	for k,v in pairs(WBi_SavedVar['characters']) do
		
		info = UIDropDownMenu_CreateInfo();
		info.text = k;
		info.value = k;
		info.arg1 = ctr;
		info.func = PlayerMenuChanged;
		UIDropDownMenu_AddButton(info);
		ctr = ctr + 1;
	end
end

local function GetTotals()
	for k,v in pairs(WBi_SavedVar['characters']) do
			addon.totals['losses'] = addon.totals['losses'] + (WBi_SavedVar['characters'][k]['games'] - (WBi_SavedVar['characters'][k]['cancel'] + WBi_SavedVar['characters'][k]['wins']));
			addon.totals['cancels'] = addon.totals['cancels'] + WBi_SavedVar['characters'][k]['cancel'];
			addon.totals['games'] = addon.totals['games'] + WBi_SavedVar['characters'][k]['games'];
			addon.totals['wins'] = addon.totals['wins'] + WBi_SavedVar['characters'][k]['wins'];
			addon.totals['overall'] = addon.totals['overall'] + WBi_SavedVar['characters'][k]['overall'];
	end
	addon.totals['winP'] = (addon.totals['wins'] / (addon.totals['games'] - addon.totals['cancels'])) * 100;
	addon.totals['canP'] = (addon.totals['cancels'] / addon.totals['games']) * 100;
	addon.totals['ratio'] = addon.totals['wins'] / addon.totals['losses'];
end

local function initStats()
	local gRatio = WBi_SavedVar['totWinning'] / WBi_SavedVar['totLosing']
	UIDropDownMenu_SetSelectedID(PlayerMenu, 1);
	UIDropDownMenu_SetSelectedValue(PlayerMenu, "Overall")
	UIDropDownMenu_SetText(PlayerMenu, "Overall");
	
	GetTotals();
	HighWinFrame:SetText(BreakUpLargeNumbers(WBi_SavedVar['highWin']).."g");
	HighLoseFrame:SetText(WBi_SavedVar['highLose']);
	LongGameFrame:SetText(WBi_SavedVar['longest']);
	WorstRollFrame:SetText(WBi_SavedVar['worst']['roll']);
	WorstChanceFrame:SetText(WBi_SavedVar['worst']['chance']);
	TotalWinFrame:SetText(BreakUpLargeNumbers(WBi_SavedVar['totWinning']).."g");
	TotalLoseFrame:SetText(BreakUpLargeNumbers(WBi_SavedVar['totLosing']).."g");
	GoldRatioFrame:SetText(tostring(("%.1f"):format(gRatio)));
	GamesFrame:SetText(addon.totals['games']);
	WinFrame:SetText(addon.totals['wins']);
	LossFrame:SetText(addon.totals['losses']);
	WinRatioFrame:SetText(tostring(("%.1f"):format(addon.totals['ratio'])));
	CancelFrame:SetText(addon.totals['cancels']);
	WinPercFrame:SetText(tostring(("%.1f"):format(addon.totals['winP'])).."%");
	CancelPercFrame:SetText(tostring(("%.1f"):format(addon.totals['canP'])).."%");
	BalanceFrame:SetText(BreakUpLargeNumbers(addon.totals['overall']).."g");
end

local function initAddon(e,...)
	local arg1 = select(1,...); -- AddOn Name
	
	if (arg1 == name) then
		if (addon.vars['isClientValid'] ~= "US") then
			addon.initWarningFrame(warning);
			warning:Show();
		else
			if (version < "b1.2" and (WBi_SavedVar['version'] ~= version or WBi_SavedVar['version'] == nil)) then
				WBi_SavedVar = nil;
			end
			if (WBi_SavedVar == nil) then
				WBi_SavedVar = {};
				--[[WBi_SavedVar['overall'] = 0;
				WBi_SavedVar['wins'] = 0;
				WBi_SavedVar['cancel'] = 0;
				WBi_SavedVar['games'] = 0;]]
				WBi_SavedVar['version'] = version;
				WBi_SavedVar['highWin'] = 0;
				WBi_SavedVar['highLose'] = 0;
				WBi_SavedVar['longest'] = 0;
				WBi_SavedVar['totWinning'] = 0;
				WBi_SavedVar['totLosing'] = 0;
				WBi_SavedVar['ratio'] = 0;
				WBi_SavedVar['worst'] = {};
				WBi_SavedVar['worst']['roll'] = 0;
				WBi_SavedVar['worst']['chance'] = 0;
				WBi_SavedVar['numChars'] = 1;
				WBi_SavedVar['characters'] = {};
				WBi_SavedVar['characters'][UnitName("player")] = {};
				WBi_SavedVar['characters'][UnitName("player")]['wins'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['cancel'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['games'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['ratio'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['overall'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Main'] = {};
				WBi_SavedVar['characters'][UnitName("player")]['Main']['A'] = "TOPLEFT";
				WBi_SavedVar['characters'][UnitName("player")]['Main']['X'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Main']['Y'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Stat'] = {};
				WBi_SavedVar['characters'][UnitName("player")]['Stat']['A'] = "TOPLEFT";
				WBi_SavedVar['characters'][UnitName("player")]['Stat']['X'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Stat']['Y'] = 0;
			end
			
			if (WBi_SavedVar['characters'][UnitName("player")] == nil) then
				WBi_SavedVar['numChars'] = WBi_SavedVar['numChars'] + 1;
				WBi_SavedVar['characters'][UnitName("player")] = {};
				WBi_SavedVar['characters'][UnitName("player")]['wins'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['cancel'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['games'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['ratio'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['overall'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Main'] = {};
				WBi_SavedVar['characters'][UnitName("player")]['Main']['A'] = "TOPLEFT";
				WBi_SavedVar['characters'][UnitName("player")]['Main']['X'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Main']['Y'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Stat'] = {};
				WBi_SavedVar['characters'][UnitName("player")]['Stat']['A'] = "TOPLEFT";
				WBi_SavedVar['characters'][UnitName("player")]['Stat']['X'] = 0;
				WBi_SavedVar['characters'][UnitName("player")]['Stat']['Y'] = 0;
			end
			
			if (WBi_SavedVar['version'] ~= version) then
				WBi_SavedVar['version'] = version;
			end
			-- INITIALIZE FRAMES --
			addon.initMainFrame(main);
			addon.initStatsFrame(stat);
			addon.initCheckFrame(check);
			addon.initMainFrameFunctions();
			initFrameVars();
			initPlayerMenu();
			
			
			WBiLauncher = WBi.ldb:NewDataObject(name, {
				 type = "launcher",
				 icon = "Interface\\ICONS\\INV_Misc_Coin_01",
				 OnTooltipShow = function(tooltip)
					  tooltip:SetText("WoW Bets")
					  tooltip:Show()
				 end,
				 OnClick = function(self, button)
					local x,y = WBi_SavedVar['characters'][UnitName("player")]['Main']['X'], WBi_SavedVar['characters'][UnitName("player")]['Main']['Y'];

					
					if (stat:IsShown()) then
						if (x == 0 and y == 0) then
							main:SetPoint("TOPLEFT", 230, -50);
						end
					else 
						if (x == 0 and y == 0) then
							main:SetPoint("TOPLEFT", 25, -50);
						end
					end
					if (main:IsShown()) then
						main:Hide();
					else
						main:Show();
						PlayerBox:SetFocus();
					end
				 end
			})

			WBi.ldbIcon:Register(name, WBiLauncher, WBi_SavedVar['characters'][UnitName("player")])

			events:RegisterEvent("CHAT_MSG_BN_WHISPER");
			events:RegisterEvent("CHAT_MSG_WHISPER");
			events:RegisterEvent("CHAT_MSG_WHISPER_INFORM");
			
			events:RegisterEvent("PLAYER_LOGIN");
			events:RegisterEvent("PLAYER_LOGOUT");
			
			
			initStats();
			local numChars = WBi_SavedVar['numChars'];
			
			UIDropDownMenu_Initialize(PlayerMenu, initPlayerMenu);
			main:SetPoint(WBi_SavedVar['characters'][UnitName("player")]['Main']['A'], WBi_SavedVar['characters'][UnitName("player")]['Main']['X'], WBi_SavedVar['characters'][UnitName("player")]['Main']['Y']);
			stat:SetPoint(WBi_SavedVar['characters'][UnitName("player")]['Stat']['A'], WBi_SavedVar['characters'][UnitName("player")]['Stat']['X'], WBi_SavedVar['characters'][UnitName("player")]['Stat']['Y']);
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 "..name.." version "..version.." has been successfully loaded!");
		end
	end	
end

local function PlayerMenuChanged(self)
	if (self.value == "Overall") then
		initStats();
	else
		local losses = WBi_SavedVar['characters'][self.value]['games'] - (WBi_SavedVar['characters'][self.value]['cancel'] + WBi_SavedVar['characters'][self.value]['wins']);
		local perc = (WBi_SavedVar['characters'][self.value]['wins'] / (WBi_SavedVar['characters'][self.value]['games'] - WBi_SavedVar['characters'][self.value]['cancel'])) * 100;
		local canP = (WBi_SavedVar['characters'][self.value]['cancel'] / WBi_SavedVar['characters'][self.value]['games']) * 100;
		local ratio = WBi_SavedVar['characters'][self.value]['wins'] / losses;
		UIDropDownMenu_SetSelectedID(PlayerMenu, self.arg1);
		UIDropDownMenu_SetSelectedValue(PlayerMenu, self.value)
		
		
		
		TotalLabel:SetText(self.value.." Totals");
		GamesFrame:SetText(WBi_SavedVar['characters'][self.value]['games']);
		WinFrame:SetText(WBi_SavedVar['characters'][self.value]['wins']);
		LossFrame:SetText(losses);
		WinRatioFrame:SetText(tostring(("%.1f"):format(ratio)));
		CancelFrame:SetText(WBi_SavedVar['characters'][self.value]['cancel']);
		WinPercFrame:SetText(tostring(("%.1f"):format(perc)).."%");
		CancelPercFrame:SetText(tostring(("%.1f"):format(canP)).."%");
		BalanceFrame:SetText(BreakUpLargeNumbers(WBi_SavedVar['characters'][self.value]['overall']).."g");
	end
end

local function processBNetInfo(e,...)
	local arg1 = select(1,...); -- BNet Message
	local arg2 = select(2,...); -- Friend's Name
	
	local numFriends = BNGetNumFriends();
	local numToons;
	
	for i=1,numFriends do
		local info = {BNGetFriendInfo(i)};
		if (info[2] == arg2) then
			numToons = BNGetNumFriendToons(i);
			for j=1,numToons do
				local toons = {BNGetFriendToonInfo(i,j)};
				
				if (toons[2] == info[5]) then
					return info[5],toons[4];
				end
			end
		end
	end
end

local function processBet(e,...)
	local arg1 = select(1,...); -- Bet Message
	local arg2 = select(5,...); -- Message Sender
	local arg3 = select(9,...); -- Channel Name
	local arg4 = select(2,...); -- Message Sender (with Realm Name)
	local isRoll = string.find(arg1, " rolled ");
	local isBet = string.find(arg1, " has bet ");
	local isLost = string.find(arg1, " lost!");
	local isCancel = string.find(arg1, " cancelled!");
	local isRemote = string.find(arg2,"-");
	
	if (isRemote ~= nil) then
		arg2 = { strsplit("-",arg2)};
		arg2 = arg2[1];
	end
	--[[print("CHANNEL NAME: '"..tostring(arg3).."'");
	if (arg3 == "WoWBets") then
		print("\nNAME: '"..tostring(arg2).."'\nHAS ROLLED: '"..tostring(isRoll).."'");
	end]]

	if (arg2 == addon.vars['guestName'] and arg3 == "WoWBets") then
		if (isRoll ~= nil) then -- Example Roll: "Sweetsour rolled 354 (0.28%)"
			local args = {strsplit(" ",arg1)};
			local chance;
			
			CurrentRollFrame:SetText(args[3]);
			addon.vars['rollOutcome'] = tonumber(args[3]);
			chance = addon.GetChance(addon.vars['rollOutcome']);
			ChanceFrame:SetText(chance.."% to lose");
			addon.vars['rollCount'] = addon.vars['rollCount'] + 1;
			addon.ModFuncBtn("call",true);
			addon.CheckProgress(addon.vars['rollOutcome'])
		elseif (isLost ~= nil) then
			if (addon.vars['curBid'] > WBi_SavedVar['highWin']) then
				WBi_SavedVar['highWin'] = addon.vars['curBid'];
			end
			WBi_SavedVar['totWinning'] = WBi_SavedVar['totWinning'] + addon.vars['curBid'];
			WBi_SavedVar['characters'][UnitName("player")]['wins'] = WBi_SavedVar['characters'][UnitName("player")]['wins'] + 1;
			WBi_SavedVar['characters'][UnitName("player")]['overall'] = WBi_SavedVar['characters'][UnitName("player")]['overall'] + addon.vars['curBid'];
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['wins'] = WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['wins'] + 1;
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['overall'] = WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['overall'] + addon.vars['curBid'];
			addon.EndGame(1,UnitName("player"),"You Won!");
		elseif (isCancel ~= nil) then
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['cancel'] = WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['cancel'] + 1;
			addon.EndGame(0,"CANCELLED","Clear Game");
		end
	end
end

local function SetupGuest(e,...)
	if (e == "CHAT_MSG_BN_WHISPER") then
		addon.vars['guestName'],addon.vars['guestRealm'] = processBNetInfo(event,...);
	elseif (e == "CHAT_MSG_WHISPER" or e == "CHAT_MSG_WHISPER_INFORM") then
		local playerAll = select(2,...);
		local player = select(5,...);
		local isRemote = string.find(player, "-");
		playerAll = { strsplit("-",playerAll)};
		
		if (isRemote ~= nil) then
			player = { strsplit("-",player)};
			player = player[1];
		end

		addon.vars['guestName'] = player;
		addon.vars['guestRealm'] = playerAll[2];
		addon.vars['guestFullName'] = player.."-"..playerAll[2];
	end
end

local function OnlineCheck(e,...)
	local player = PlayerBox:GetText();
	local realm = RealmBox:GetText();
	local response = select(1,...);
	
	if (e == "CHAT_MSG_WHISPER_INFORM") then
		response = string.find(response, "WoW Bets?");
		if (response ~= nil) then
			addon.vars['isOnline'] = true;
			SetupGuest(e,...);
			CancelInviteBtn:Show();
		end
	elseif (e == "CHAT_MSG_SYSTEM") then
		if (response == "No player named '"..player.."-"..realm.."' is currently playing.") then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 That player is not currently online.");
			addon.vars['checkName'] = nil;
			addon.ResetGame('full');
			events:UnregisterEvent("CHAT_MSG_SYSTEM");
		end
	end
end

local function playCheck(e,...)
	local msg = select(1,...);
	local player;
	local isOffer = string.find(msg, "WoW Bets?");
	local isGold = string.find(msg, "I don't have that much gold");
	
	if (msg == "Cancelled Invitation") then
		local realm;
		
		if (e == "CHAT_MSG_BN_WHISPER") then
			player,realm = processBNetInfo(event,...);
		elseif (e == "CHAT_MSG_WHISPER" or e == "CHAT_MSG_WHISPER_INFORM") then
			player = select(5,...);
			local isRemote = string.find(player, "-");
			
			if (isRemote ~= nil) then
				player = { strsplit("-",player)};
				player = player[1];
			end
		end
	end

	--print("CHECK: '"..tostring(addon.vars['playCheck']).."'\nGUEST: '"..tostring(addon.vars['guestName']).."'\nNAME: '"..tostring(addon.vars['checkName']).."'");
	if (isOffer ~= nil) then
		local b = select(2,strsplit("?",msg));
		local initBid = gsub(b,"g","")
		SetupGuest(e,...);
		addon.vars['curBid'] = tonumber(initBid);
		OfferLabel:SetText(b);
		check:Show();
	elseif (msg == "Sure" and addon.vars['playCheck'] == true and addon.vars['guestName'] == addon.vars['checkName'] and addon.vars['guestName'] ~= nil and addon.vars['checkName'] ~= nil) then
		local channelCheck = GetChannelName("WoWBets");
		local chance = addon.GetChance(addon.vars['curBid']);
		addon.ModFuncBtn("start-cancel",true);
		--[[addon.MainFrame.StartBtn:Enable();
		addon.MainFrame.StartBtn:SetAlpha(1);
		addon.MainFrame.CancelBtn:Enable();
		addon.MainFrame.CancelBtn:SetAlpha(1);]]
		--[[addon.MainFrame.CloseBtn:Enable();
		addon.MainFrame.CloseBtn:SetAlpha(1);]]
		CloseMainBtn:Hide();
		main:SetHeight(278);
		EnemyFrame:SetText(addon.vars['guestName']);
		CurrentBetFrame:SetText(addon.vars['curBid'].."g");
		CurrentRollFrame:SetText(addon.vars['curBid']);
		ChanceFrame:SetText(chance.."% to lose");
		--addon.MainFrame.InviteBtn:Show();
		--addon.MainFrame.CancelInviteBtn:Hide();
		addon.ModEditArea("hide");

		if (channelCheck == 0) then
			JoinChannelByName("WoWBets");
			ChatFrame_AddChannel(DEFAULT_CHAT_FRAME, "WoWBets");
		end
		addon.vars['channel'] = GetChannelName("WoWBets");
		ChangeChatColor("CHANNEL"..addon.vars['channel'],0/255,255/255,255/255);
		addon.vars['checkName'] = nil;
		events:RegisterEvent("CHAT_MSG_CHANNEL");

		if (WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']] == nil) then
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']] = {};
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['games'] = 1;
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['wins'] = 0;
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['cancel'] = 0;
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['overall'] = 0;
		else
			WBi_SavedVar['characters'][UnitName("player")]['games'] = WBi_SavedVar['characters'][UnitName("player")]['games'] + 1;
			WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['games'] = WBi_SavedVar['characters'][UnitName("player")][addon.vars['guestFullName']]['games'] + 1;
		end		
	elseif ((msg == "No thanks" or isGold ~= nil) and addon.vars['playCheck'] == true and addon.vars['guestName'] == addon.vars['checkName'] and addon.vars['guestName'] ~= nil and addon.vars['checkName'] ~= nil) then
		if (msg == "No thanks") then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 "..addon.vars['guestName'].." has declined.");
		elseif (isGold ~= nil) then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 "..addon.vars['guestName'].." does not have enough gold for that bet.");
		end
		addon.ResetGame('full');
		addon.vars['checkName'] = nil;
		addon.vars['playCheck'] = nil;
	elseif (msg == "Cancelled Invitation" and addon.vars['guestName'] == player and addon.vars['guestName'] ~= nil) then
		if (check:IsShown()) then
			check:Hide();
		end
		addon.vars['guestName'] = nil;
	end
end

function addon.EndGame(roll,winner,text)
	events:UnregisterEvent("CHAT_MSG_CHANNEL");
	addon.ModFuncBtn("all",false);
	CurrentRollFrame:SetText(roll);
	ChanceFrame:SetText("N/A");
	WinnerFrame:SetText(winner);
	main:SetHeight(220);
	EndGameBtn:SetText(text);
	EndGameBtn:Show();
end

function addon.GetChance(roll)
	local chance = (1 / roll) * 100;
	local decimals;
	
	if (chance > 10) then
		decimals = 1;
	else
		decimals = 2;
	end
	return tonumber(("%."..tostring(decimals).."f"):format(chance));
end

function addon.CheckProgress(roll)
	local progress = (roll / addon.vars['curBid']) * 100;
	if (progress > 50) then
		addon.ModFuncBtn("cancel",true);
	else
		addon.ModFuncBtn("cancel",false);
	end
end

function addon.ModEditArea(state)
	if (state == "hide") then
		InputGrp:Hide();
		StatusGrp:SetPoint("TOP",0,-75);
		main:SetHeight(193);
	else
		InputGrp:Show();
		StatusGrp:SetPoint("TOP",0,-180);
		main:SetHeight(325);
	end
end


function addon.ModFuncBtn(type,enable)
	if (type == "all" or type == "start" or type == "start-cancel" or type == "start-call") then
		if (not enable) then
			StartBtn:Disable();
			StartBtn:SetAlpha(0.4);
		else
			StartBtn:Enable();
			StartBtn:SetAlpha(1);
		end
	end
	
	if (type == "all" or type == "call" or type == "start-call" or type == "call-cancel") then
		if (not enable) then
			CallBtn:Disable();
			CallBtn:SetAlpha(0.4);
		else
			CallBtn:Enable();
			CallBtn:SetAlpha(1);
		end
	end
	
	if (type == "all" or type == "cancel" or type == "start-cancel" or type == "call-cancel") then
		if (not enable) then
			CancelBtn:Disable();
			CancelBtn:SetAlpha(0.4);
		else
			CancelBtn:Enable();
			CancelBtn:SetAlpha(1);
		end
	end
end

function addon.EditBoxState(type,enable)
	if (enable) then
		if (type == "full") then
			PlayerBox:SetText("");
			RealmBox:SetText(addon.vars['myRealm']);
			AmountBox:SetText("");
		end
		
		PlayerBox:Enable();
		PlayerBox:SetAlpha(1);
		RealmBox:Enable();
		RealmBox:SetAlpha(1);
		AmountBox:Enable();
		AmountBox:SetAlpha(1);
	else
		PlayerBox:Disable();
		PlayerBox:SetAlpha(0.4);
		RealmBox:Disable();
		RealmBox:SetAlpha(0.4);
		AmountBox:Disable();
		AmountBox:SetAlpha(0.4);
	end
end

function addon.ResetGame(type)
	addon.vars['guestName'] = nil;
	addon.vars['guestRealm'] = nil;
	addon.vars['guestFullName'] = nil;
	addon.vars['isStarted'] = false;
	addon.vars['curBid'] = 0;
	addon.vars['rollCount'] = 0;
	addon.vars['rollOutcome'] = 0;
	
	addon.ModFuncBtn('all',false);
	
	addon.EditBoxState(type,true);
	InviteBtn:Show();
	CancelInviteBtn:Hide();
	
	-- Clear Status Area
	EnemyFrame:SetText("");
	CurrentBetFrame:SetText("");
	CurrentRollFrame:SetText("");
	ChanceFrame:SetText("");
	WinnerFrame:SetText("");
	
	CloseMainBtn:Show();
	
	-- Show EditBox Group
	addon.ModEditArea("show");
end

events:HookScript("OnEvent", function(self,event,...)
	if (addon.vars['isClientValid'] ~= "US") then
		initAddon(event,...);
	else
		if (event == "CHAT_MSG_BN_WHISPER" or event == "CHAT_MSG_WHISPER") then
			playCheck(event,...);
			
			--addon.processBet(event,"bnet",...);
		--[[elseif (event == "CHAT_MSG_WHISPER") then
			addon.processBet(event,"normal",...);
		elseif (event == "CHAT_MSG_SYSTEM") then
			addon.OnlineCheck(event,...);]]
		elseif (event == "CHAT_MSG_WHISPER_INFORM" or event == "CHAT_MSG_SYSTEM") then
			OnlineCheck(event,...);
		elseif (event == "CHAT_MSG_CHANNEL") then
			processBet(event,...);
		elseif (event == "ADDON_LOADED") then
			initAddon(event,...);
		elseif (event == "PLAYER_LOGOUT") then
			local mP,_,_,mX,mY = main:GetPoint(1);
			local sP,_,_,sX,sY = stat:GetPoint(1);
			
			WBi_SavedVar['characters'][UnitName("player")]['Main']['A'] = mP;
			WBi_SavedVar['characters'][UnitName("player")]['Main']['X'] = mX;
			WBi_SavedVar['characters'][UnitName("player")]['Main']['Y'] = mY;
			WBi_SavedVar['characters'][UnitName("player")]['Stat']['A'] = sP;
			WBi_SavedVar['characters'][UnitName("player")]['Stat']['X'] = sX;
			WBi_SavedVar['characters'][UnitName("player")]['Stat']['Y'] = sY;
		end
	end
end);


SLASH_WBIADDON1 = '/wbi';
function SlashCmdList.WBIADDON(msg, editbox)
	if (addon.vars['isClientValid'] ~= "US") then
		DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 Due to ToS Restrictions for your region, this addon has been prevented from loading. Sorry!");
	else
		if (msg == '' or msg == 'help') then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFFFF  --WoW Bets--\n/wbi help - Display help information\n/wbi show - Display main game frame\n/wbi stats - Display game statistics frame");
		elseif (msg == "show" or msg == "open") then
			local x,y = WBi_SavedVar['characters'][UnitName("player")]['Main']['X'], WBi_SavedVar['characters'][UnitName("player")]['Main']['Y'];
			--addon.EventFrame:RegisterEvent("CHAT_MSG_CHANNEL");
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 WoW Bets is now online.");
			addon.vars['isOpen'] = true;
			main:Show();
			if (stat:IsShown()) then
				if (x == 0 and y == 0) then
					main:SetPoint("TOPLEFT", 230, -50);
				end
			else 
				if (x == 0 and y == 0) then
					main:SetPoint("TOPLEFT", 25, -50);
				end
			end
			PlayerBox:SetFocus();
		elseif (msg == "hide" or msg == "close") then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 WoW Bets is now offline.");
			addon.vars['isOpen'] = false;
			main:Hide();
		elseif (msg == "stats" or msg == "totals" or msg == "stat" or msg == "statistics") then
			local x,y = WBi_SavedVar['characters'][UnitName("player")]['Stat']['X'], WBi_SavedVar['characters'][UnitName("player")]['Stat']['Y'];
			
			stat:Show();
			if (main:IsShown()) then
				if (x == 0 and y == 0) then
					stat:SetPoint("TOPLEFT", 230, -50);
				end
			else
				if (x == 0 and y == 0) then
					stat:SetPoint("TOPLEFT", 25, -50);
				end
			end
		elseif (msg == "version") then
			DEFAULT_CHAT_FRAME:AddMessage("|cFFFFFF00 WoW Bets Version: "..version);
		end
	end
end